﻿<?php

	class Database {
		
		private $host = DB_HOST;
		private	$user = DB_USER;
		private $pass = DB_PASS;
		private $dbname = DB_NAME;
		
		private $dbh;
		private $error;
		private $stmt;
		
		/*
		*	Constructor function
		*/
		public function __construct() {
			
			// Set DSN
			$dsn = 'mysql:host=' . $this->host . ';dbname=' . $this->dbname;
			
			// Set options
			$options = array (
				PDO::ATTR_PERSISTENT => true,
				PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION
			);
			
			// Create a new PDO instance
			try {
				$this->dbh = new PDO($dsn, $this->user, $this->pass, $options);
			} catch (PDOException $e) {
				$this->error = $e->getMessage();
			}
			
		}
		
		public function query($query) {
		
			$this->stmt = $this->dbh->prepare($query);
			
		}
		
		public function bind($param, $value, $type=null) {
			
			if (is_null($type)) {
				switch (true) {
					case is_int($value) :
						$type = PDO::PARAM_INT;
						break;
					case is_bool($value) :
						$type = PDO::PARAM_BOOL;
						break;
					case is_null($value) :
						$type = PDO::PARAM_NULL;
						break;
					default :
						$type = PDO::PARAM_STR;
						break;		
				}
			}
			
			$this->stmt->bindvalue($param, $value, $type);
			
		}
		
		public function execute() {
			
			return $this->stmt->execute();
			
		}
		
		/*
		*	Get result set of a db query (more than one record)
		*/
		public function getResultSet() {
			
			$this->execute();
			return $this->stmt->fetchAll(PDO::FETCH_OBJ);
			
		}
		
		/*
		*	Get single row from a db query 
		*/
		public function getSingle() {
			
			$this->execute();
			return $this->stmt->fetch(PDO::FETCH_OBJ);
			
		}	
		
		/*
		*	Get number of rows 
		*/
		public function getRowCount() {
		
			return $this->stmt->rowCount();
			
		}
		
		/*
		*	Get ID of last inserted record
		*/
		public function getLastInsertId() {
			
			return $this->dbh->lastInsertId();
			
		}
		
	}